@@ -41,8 +41,13 @@ namespace Dasher {
     int GetNumberSymbols() const {
       return m_Characters.size();
     }                           // return size of alphabet
-    // Return number of text symbols 
+
+    /// Return number of text symbols 
+    /// Text symbols are everything which doesn't generate a new root, 
+    /// i.e. control mode and conversion mode
     int GetNumberTextSymbols() const {
+
+      // TODO: This really does need to be fixed, as this will sometimes be 2
       return m_Characters.size() - 1;
     } 
 
@@ -67,9 +72,9 @@ namespace Dasher {
     symbol GetParagraphSymbol() const;
     symbol GetSpaceSymbol() const;
     symbol GetControlSymbol() const;
-    //-- Added for Kanji Conversion 13 July 2005 by T.Kaburagi
     symbol GetStartConversionSymbol() const;
     symbol GetEndConversionSymbol() const;
+    symbol GetResetSymbol() const;
 
     const std::string & GetDisplayText(symbol i) const {
       return m_Display[i];
@@ -128,9 +133,9 @@ namespace Dasher {
     void AddParagraphSymbol(std::string NewCharacter, std::string Display, int Colour, std::string Foreground);
     void AddSpaceSymbol(std::string NewCharacter, std::string Display, int Colour, std::string Foreground);
     void AddControlSymbol(std::string NewCharacter, std::string Display, int Colour, std::string Foreground);
-    //-- Added for Kanji Conversion 13 July 2005 by T.Kaburagi
     void AddStartConversionSymbol(std::string NewCharacter, std::string Display, int Colour, std::string Foreground);
     void AddEndConversionSymbol(std::string NewCharacter, std::string Display, int Colour, std::string Foreground);
+    void AddResetSymbol(std::string NewCharacter, std::string Display, int Colour, std::string Foreground);
 
     void SetOrientation(Opts::ScreenOrientations Orientation) {
       m_Orientation = Orientation;
@@ -169,6 +174,7 @@ namespace Dasher {
     //-- Added for Kanji Conversion 13 July 2005 by T.Kaburagi
     symbol m_StartConversionSymbol;
     symbol m_EndConversionSymbol;
+    symbol m_iResetSymbol;
 
     std::string m_TrainingFile;
     std::string m_GameModeFile;
@@ -216,6 +222,12 @@ namespace Dasher {
   inline symbol CAlphabet::GetEndConversionSymbol() const {
     return m_EndConversionSymbol;
   }
+  
+  inline symbol CAlphabet::GetResetSymbol() const {
+    return m_iResetSymbol;
+  }
+
+
 }                              // end namespace dasher
 
 #endif                          // ifndef __DASHER_ALPHABET_H__
