@@ -1,3 +1,23 @@
+// AlphabetManager.h
+//
+// Copyright (c) 2007 The Dasher Team
+//
+// This file is part of Dasher.
+//
+// Dasher is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Dasher is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Dasher; if not, write to the Free Software 
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
 #ifndef __alphabetmanager_h__
 #define __alphabetmanager_h__
 
@@ -7,6 +27,7 @@
 #include "Parameters.h"
 
 class CNodeCreationManager;
+struct SGroupInfo;
 
 namespace Dasher {
 
@@ -15,11 +36,15 @@ namespace Dasher {
   /// \ingroup Model
   /// @{
 
-  /// A node manager which deals with alphabets and language models.
+  /// Implementation of CNodeManager for regular 'alphabet' nodes, ie
+  /// the basic Dasher behaviour. Child nodes are populated according
+  /// to the appropriate alphabet file, with sizes given by the
+  /// language model.
+  ///
   class CAlphabetManager : public CNodeManager {
   public:
 
-    CAlphabetManager(CDasherInterfaceBase *pInterface, CNodeCreationManager *pNCManager, CLanguageModel *pLanguageModel, CLanguageModel::Context iLearnContext, bool bGameMode, const std::string &strGameModeText);
+    CAlphabetManager(CDasherInterfaceBase *pInterface, CNodeCreationManager *pNCManager, CLanguageModel *pLanguageModel, CLanguageModel::Context iLearnContext);
 
     ///
     /// Does nothing - alphabet manager isn't reference counted.
@@ -64,6 +89,17 @@ namespace Dasher {
       int iOffset;
     };
 
+
+    struct SAlphabetData {
+      symbol iSymbol;
+      int iPhase;
+      CLanguageModel *pLanguageModel;
+      CLanguageModel::Context iContext;
+      int iGameOffset;
+      int iOffset;
+    };
+
+
   private:
     
     void BuildContext(std::string strContext, bool bRoot, CLanguageModel::Context &oContext, symbol &iSymbol);
@@ -76,19 +112,8 @@ namespace Dasher {
     CLanguageModel *m_pLanguageModel;
     CNodeCreationManager *m_pNCManager;
     CLanguageModel::Context m_iLearnContext;
-    std::string m_strGameString;
-    bool m_bGameMode;
     CDasherInterfaceBase *m_pInterface;
 
-    struct SAlphabetData {
-      symbol iSymbol;
-      int iPhase;
-      CLanguageModel *pLanguageModel;
-      CLanguageModel::Context iContext;
-      int iGameOffset;
-      int iOffset;
-    };
-
   };
   /// @}
 
