@@ -1,6 +1,22 @@
 // DasherInterfaceBase.h
 //
-// Copyright (c) 2002 Iain Murray
+// Copyright (c) 2007 The Dasher Team
+//
+// This file is part of Dasher.
+//
+// Dasher is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Dasher is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Dasher; if not, write to the Free Software 
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef __DasherInterfaceBase_h__
 #define __DasherInterfaceBase_h__
@@ -339,9 +355,13 @@ public:
     //    Start();
   };
 
-  void ScheduleRedraw() {
-    m_bRedrawScheduled = true;
-  };
+  void GameMessageIn(int message, void* messagedata);
+
+  virtual void GameMessageOut(void* gameHelper, int message, const void* messagedata) = 0;
+
+  void ScheduleRedraw() { 
+    m_bRedrawScheduled = true; 
+  }; 
 
   void CheckRedraw();
 
