@@ -7,21 +7,27 @@
 #include <libgnomevfs/gnome-vfs.h> 
 //#endif
 
-#include "dasher_action_keyboard.h"
+
 #ifdef WITH_MAEMO
 #include "dasher_action_keyboard_maemo.h"
 #else
+#include "dasher_action_keyboard.h"
+#endif
+
+#ifndef WITH_MAEMO
 #include "dasher_action_script.h"
 #endif
+
 #ifdef GNOME_SPEECH
 #include "dasher_action_speech.h"
 #endif 
+
 #include "dasher_editor_internal.h"
 #include "dasher_external_buffer.h"
 #include "dasher_internal_buffer.h"
 #include "dasher_lock_dialogue.h"
 #include "dasher_main.h"
-#include "game_mode_helper.h"
+//#include "game_mode_helper.h"
 
 // TODO: Maybe reimplement something along the lines of the following, which used to be in edit.cc
 
@@ -73,14 +79,15 @@ struct _DasherEditorInternalPrivate {
   GtkVBox *pActionPane;
   GtkClipboard *pTextClipboard;
   GtkClipboard *pPrimarySelection;
+  GtkTable *pGameGroup;
+  GtkLabel *pGameInfoLabel;
   EditorAction *pActionRing;
   EditorAction *pActionIter;
   gboolean bActionIterStarted;
   gint iNextActionID;
   IDasherBufferSet *pBufferSet;
   IDasherBufferSet *pExternalBuffer;
-  IDasherBufferSet *pInternalBuffer;
-  GameModeHelper *pGameModeHelper;
+  //  GameModeHelper *pGameModeHelper;
   GtkTextMark *pNewMark;
   DasherAppSettings *pAppSettings;
   gchar *szFilename;
@@ -121,6 +128,7 @@ static void dasher_editor_internal_display_message(DasherEditor *pSelf, DasherMe
 static void dasher_editor_internal_check_activity(DasherEditor *pSelf, EditorAction *pAction);
 static void dasher_editor_internal_action_save_state(DasherEditor *pSelf, EditorAction *pAction);
 
+static void dasher_editor_internal_command_game(DasherEditor *pSelf);
 static void dasher_editor_internal_command_new(DasherEditor *pSelf);
 static void dasher_editor_internal_command_open(DasherEditor *pSelf);
 static void dasher_editor_internal_command_save(DasherEditor *pSelf, gboolean bPrompt, gboolean bAppend);
@@ -181,6 +189,9 @@ const gchar *dasher_editor_internal_get_filename(DasherEditor *pSelf);
 const gchar *dasher_editor_internal_get_all_text(DasherEditor *pSelf);
 const gchar *dasher_editor_internal_get_new_text(DasherEditor *pSelf);
 
+static void dasher_editor_internal_handle_parameter_change(DasherEditor *pSelf, gint iParameter);
+
+
 // Private methods not in class
 extern "C" void delete_children_callback(GtkWidget *pWidget, gpointer pUserData);
 extern "C" void main_window_realized(DasherMain *pMain, gpointer pUserData);
@@ -198,37 +209,15 @@ extern "C" void protect_cb(GtkDasherControl *pDasherControl, gpointer pUserData)
 
 static void 
 dasher_editor_internal_class_init(DasherEditorInternalClass *pClass) {
-  g_debug("Initialising DasherEditor");
-
   g_type_class_add_private(pClass, sizeof(DasherEditorInternalPrivate));
 
   GObjectClass *pObjectClass = (GObjectClass *) pClass;
   pObjectClass->finalize = dasher_editor_internal_finalize;
 
-  // /* Setup signals */
-//   dasher_editor_internal_signals[FILENAME_CHANGED] = g_signal_new("filename-changed", G_TYPE_FROM_CLASS(pClass), 
-// 							 static_cast < GSignalFlags > (G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION), 
-// 							 G_STRUCT_OFFSET(DasherEditorClass, filename_changed), 
-// 							 NULL, NULL, g_cclosure_marshal_VOID__VOID, 
-// 							 G_TYPE_NONE, 0);
-
-//   dasher_editor_internal_signals[BUFFER_CHANGED] = g_signal_new("buffer-changed", G_TYPE_FROM_CLASS(pClass), 
-// 						       static_cast < GSignalFlags > (G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION), 
-// 						       G_STRUCT_OFFSET(DasherEditorClass, buffer_changed), 
-// 						       NULL, NULL, g_cclosure_marshal_VOID__VOID, 
-// 						       G_TYPE_NONE, 0);
-
-//   dasher_editor_internal_signals[CONTEXT_CHANGED] = g_signal_new("context-changed", G_TYPE_FROM_CLASS(pClass), 
-// 							static_cast < GSignalFlags > (G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION), 
-// 							G_STRUCT_OFFSET(DasherEditorClass, context_changed), 
-// 							NULL, NULL, g_cclosure_marshal_VOID__VOID, 
-// 							G_TYPE_NONE, 0);
-
   DasherEditorClass *pParentClass = (DasherEditorClass *)pClass;
 
   pParentClass->initialise = dasher_editor_internal_initialise;
   pParentClass->command = dasher_editor_internal_command;
-  pParentClass->handle_font = dasher_editor_internal_handle_font;
   pParentClass->output = dasher_editor_internal_output;
   pParentClass->delete_text = dasher_editor_internal_delete;
   pParentClass->get_context = dasher_editor_internal_get_context;
@@ -248,7 +237,7 @@ dasher_editor_internal_class_init(DasherEditorInternalClass *pClass) {
   pParentClass->get_filename = dasher_editor_internal_get_filename;
   pParentClass->get_all_text = dasher_editor_internal_get_all_text;
   pParentClass->get_new_text = dasher_editor_internal_get_new_text;
-
+  pParentClass->handle_parameter_change = dasher_editor_internal_handle_parameter_change;
 }
 
 static void 
@@ -256,21 +245,18 @@ dasher_editor_internal_init(DasherEditorInternal *pDasherControl) {
   DasherEditorInternalPrivate *pPrivate = DASHER_EDITOR_INTERNAL_GET_PRIVATE(pDasherControl);
 
   pPrivate->pBufferSet = NULL;
-  pPrivate->pInternalBuffer = NULL;
   pPrivate->pExternalBuffer = NULL;
   pPrivate->szFilename = NULL;
   pPrivate->pTextClipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
   pPrivate->pPrimarySelection = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
   pPrivate->pActionRing = NULL;
   pPrivate->iNextActionID = 0;
-  pPrivate->pGameModeHelper = NULL;
+  //  pPrivate->pGameModeHelper = NULL;
   pPrivate->bFileModified = FALSE;
 }
 
 static void 
 dasher_editor_internal_finalize(GObject *pObject) {
-  g_debug("Finalising DasherEditor");
-
   DasherEditorInternalPrivate *pPrivate = DASHER_EDITOR_INTERNAL_GET_PRIVATE(pObject);
 
   EditorAction *pCurrentAction = pPrivate->pActionRing;
@@ -299,17 +285,15 @@ dasher_editor_internal_new() {
   DasherEditorInternal *pDasherEditor;
   pDasherEditor = (DasherEditorInternal *)(g_object_new(dasher_editor_internal_get_type(), NULL));
 
-
   g_pEditor = pDasherEditor;
 
   DasherEditorInternalPrivate *pPrivate = DASHER_EDITOR_INTERNAL_GET_PRIVATE(pDasherEditor);
   
-
-  //  GtkPaned *pPane = GTK_PANED(glade_xml_get_widget(pGladeXML, "main_divider"));
-  
   GtkWidget *pScrolledWindow = gtk_scrolled_window_new(NULL, NULL);
 
   GtkWidget *pTextView = gtk_text_view_new();
+  gtk_widget_grab_focus(pTextView);
+  
 
   pPrivate->pTextView = GTK_TEXT_VIEW(pTextView);
 
@@ -341,10 +325,13 @@ dasher_editor_internal_initialise(DasherEditor *pSelf, DasherAppSettings *pAppSe
   pPrivate->pAppSettings = pAppSettings;
   pPrivate->pDasherMain = pDasherMain;
 
-
-    //GtkTextView *pTextView = GTK_TEXT_VIEW(glade_xml_get_widget(pGladeXML, "the_text_view"));
+  dasher_editor_internal_handle_font(pSelf,
+				     dasher_app_settings_get_string(pPrivate->pAppSettings, 
+								    APP_SP_EDIT_FONT));
   
   GtkVBox *pActionPane = GTK_VBOX(glade_xml_get_widget(pGladeXML, "vbox39"));
+  pPrivate->pGameGroup = GTK_TABLE(glade_xml_get_widget(pGladeXML, "game_group"));
+  pPrivate->pGameInfoLabel = GTK_LABEL(glade_xml_get_widget(pGladeXML, "game_info_label"));
   pPrivate->pBuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(pPrivate->pTextView));
 
   gtk_widget_show_all(GTK_WIDGET(pPrivate->pTextView));
@@ -367,6 +354,8 @@ dasher_editor_internal_initialise(DasherEditor *pSelf, DasherAppSettings *pAppSe
     dasher_editor_internal_generate_filename(pSelf);
     dasher_editor_internal_clear(pSelf, false);
   }
+  
+//  pPrivate->pGameModeHelper = GAME_MODE_HELPER(game_mode_helper_new(pGladeXML, (void*)pSelf));
 }
 
 static void 
@@ -409,6 +398,12 @@ dasher_editor_internal_clipboard(DasherEditor *pSelf, clipboard_action act) {
   delete end;
 }
 
+void dasher_editor_internal_cleartext(DasherEditorInternal *pSelf)
+{
+  dasher_editor_internal_clear((DasherEditor *)pSelf, true);
+
+}
+
 void 
 dasher_editor_internal_handle_stop(DasherEditor *pSelf) {
   DasherEditorInternalPrivate *pPrivate = DASHER_EDITOR_INTERNAL_GET_PRIVATE(pSelf);
@@ -614,15 +609,8 @@ dasher_editor_internal_create_buffer(DasherEditor *pSelf) {
   if(!(pPrivate->pExternalBuffer))
     pPrivate->pExternalBuffer = IDASHER_BUFFER_SET(dasher_external_buffer_new());
     
-  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == 2) {
-    pPrivate->pBufferSet = pPrivate->pExternalBuffer;
-  }
-  else {
-    if(!(pPrivate->pInternalBuffer))
-      pPrivate->pInternalBuffer = IDASHER_BUFFER_SET(dasher_internal_buffer_new(pPrivate->pTextView));
-    
-    pPrivate->pBufferSet = pPrivate->pInternalBuffer;
-  }
+  if(!(pPrivate->pBufferSet))
+    pPrivate->pBufferSet = IDASHER_BUFFER_SET(dasher_internal_buffer_new(pPrivate->pTextView));
 
   // TODO: Fix this
   g_signal_connect(G_OBJECT(pPrivate->pBufferSet), "offset_changed", G_CALLBACK(context_changed_handler), pSelf);
@@ -654,8 +642,8 @@ dasher_editor_internal_output(DasherEditor *pSelf, const gchar *szText, int iOff
   if(pPrivate->pBufferSet)
     idasher_buffer_set_insert(pPrivate->pBufferSet, szText, iOffset);
 
-  if(pPrivate->pGameModeHelper)
-    game_mode_helper_output(pPrivate->pGameModeHelper, szText);
+//   if(pPrivate->pGameModeHelper)
+//     game_mode_helper_output(pPrivate->pGameModeHelper, szText);
 
   pPrivate->bFileModified = TRUE;
 }
@@ -667,8 +655,8 @@ dasher_editor_internal_delete(DasherEditor *pSelf, int iLength, int iOffset) {
   if(pPrivate->pBufferSet)
     idasher_buffer_set_delete(pPrivate->pBufferSet, iLength, iOffset);
 
-  if(pPrivate->pGameModeHelper)
-    game_mode_helper_delete(pPrivate->pGameModeHelper, iLength);
+//   if(pPrivate->pGameModeHelper)
+//     game_mode_helper_delete(pPrivate->pGameModeHelper, iLength);
 
   pPrivate->bFileModified = TRUE;
 }
@@ -948,6 +936,11 @@ dasher_editor_internal_command(DasherEditor *pSelf, const gchar *szCommand) {
     return TRUE;
   }
  
+  if(!strcmp(szCommand, "game")) { // Launch game mode
+    dasher_editor_internal_command_game(pSelf);
+    
+    return TRUE;
+  }
 
   /* TODO: We need a rethink here */
   const gchar *szForwardCommand = NULL;
@@ -1334,6 +1327,27 @@ dasher_editor_internal_action_save_state(DasherEditor *pSelf, EditorAction *pAct
   dasher_app_settings_set_free_long(pPrivate->pAppSettings, szRegistryName, iState);
 }
 
+static void
+dasher_editor_internal_command_game(DasherEditor *pSelf) {
+  DasherEditorInternalPrivate *pPrivate = DASHER_EDITOR_INTERNAL_GET_PRIVATE(pSelf);
+
+//   bool bGameMode = dasher_app_settings_get_bool(pPrivate->pAppSettings, BP_GAME_MODE );
+//   if(bGameMode)
+//     {
+//       gtk_widget_hide(GTK_WIDGET(pPrivate->pGameGroup));
+//       gtk_widget_hide(GTK_WIDGET(pPrivate->pGameInfoLabel));
+//     }
+//   else
+//     {
+//       gtk_widget_show(GTK_WIDGET(pPrivate->pGameGroup));
+//       gtk_widget_show(GTK_WIDGET(pPrivate->pGameInfoLabel));
+//     }
+
+  dasher_editor_internal_clear(pSelf, false);
+
+  //  dasher_app_settings_set_bool(pPrivate->pAppSettings,  BP_GAME_MODE , !bGameMode);
+}
+
 static void 
 dasher_editor_internal_command_new(DasherEditor *pSelf) {
   dasher_editor_internal_new_buffer(pSelf, NULL);
@@ -1647,6 +1661,18 @@ dasher_editor_internal_new_buffer(DasherEditor *pSelf, const gchar *szFilename)
   //  g_signal_emit_by_name(G_OBJECT(pSelf), "buffer_changed", G_OBJECT(pSelf), NULL, NULL);
 }
 
+static void
+dasher_editor_internal_handle_parameter_change(DasherEditor *pSelf, gint iParameter) {
+  DasherEditorInternalPrivate *pPrivate = DASHER_EDITOR_INTERNAL_GET_PRIVATE(pSelf);
+
+  switch(iParameter) {
+  case APP_SP_EDIT_FONT:
+    dasher_editor_internal_handle_font(pSelf,
+				       dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT));
+    break;
+  }
+}
+
 /* Callback Functions */
 
 extern "C" void 
