@@ -131,7 +131,7 @@ static void dasher_main_finalize(GObject *pObject);
 static void dasher_main_setup_window_state(DasherMain *pSelf);
 static void dasher_main_setup_window_style(DasherMain *pSelf);
 static void dasher_main_setup_internal_layout(DasherMain *pSelf);
-static void dasher_main_refresh_font(DasherMain *pSelf);
+//static void dasher_main_refresh_font(DasherMain *pSelf);
 static void dasher_main_set_filename(DasherMain *pSelf);
 
 /* ... Table based menu/toolbar commands */
@@ -217,9 +217,6 @@ static void
 dasher_main_init(DasherMain *pDasherMain) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
   
-  /* TODO: define log domain */
-  g_debug("Initialising DasherMain");
-
   pPrivate->pAppSettings = NULL;
   pPrivate->pEditor = NULL;
   pPrivate->pPreferencesDialogue = NULL;
@@ -231,8 +228,6 @@ dasher_main_init(DasherMain *pDasherMain) {
 
 static void
 dasher_main_finalize(GObject *pObject) {
-  /* TODO: Need a general overview of class finalisation */
-  g_debug("Finalizing DasherMain");
 
   DasherMain *pDasherMain = DASHER_MAIN(pObject);
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
@@ -240,8 +235,8 @@ dasher_main_finalize(GObject *pObject) {
   dasher_main_save_state(pDasherMain);
 
   /* TODO: Does unref really do the right thing - check the whole ref counting situation */
-  if(pPrivate->pEditor)
-    g_object_unref(pPrivate->pEditor);
+  //  if(pPrivate->pEditor)
+  //  g_object_unref(pPrivate->pEditor);
 
   if(pPrivate->pPreferencesDialogue)
     g_object_unref(pPrivate->pPreferencesDialogue);
@@ -261,6 +256,8 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
     return g_pDasherMain;
   else {
     DasherMain *pDasherMain = (DasherMain *)(g_object_new(dasher_main_get_type(), NULL));
+    g_pDasherMain = pDasherMain;
+
     DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
 
     /* Create the app settings object */
@@ -285,6 +282,7 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
       }
     }
     else { 
+      // By default use traditional mode
       dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 0);
     }
 
@@ -379,9 +377,6 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
 
     gtk_key_snooper_install(dasher_main_key_snooper, pDasherMain);
 
-    /* Cache a file-wide static pointer to the singleton class */
-    g_pDasherMain = pDasherMain;
-
     return pDasherMain;   
   }
 }
@@ -417,6 +412,9 @@ dasher_main_load_interface(DasherMain *pSelf) {
   case 3:
     szGladeFilename = PROGDATA "/dasher.fullscreen.glade";
     break;
+  case 22:
+    szGladeFilename = PROGDATA "/dasher.debug.glade";
+    break;
   default:
     g_error("Inconsistent application style specified.");
   }
@@ -561,6 +559,23 @@ dasher_main_load_interface(DasherMain *pSelf) {
   gtk_window_set_decorated(GTK_WINDOW(pPrivate->pMainWindow), false);
 #endif
   
+  // Hide any widgets which aren't appropriate for this mode
+  
+  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == 2) {
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "dasher_menu_bar"));
+      
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_new"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_open"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_save"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_saveas"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "separatortoolitem1"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_cut"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_copy"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "tb_command_paste"));
+    gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "separatortoolitem2"));
+  }
+    
+  
   dasher_main_connect_menus(pSelf);
 
 
@@ -598,10 +613,10 @@ dasher_main_handle_parameter_change(DasherMain *pSelf, int iParameter) {
     else
       gtk_widget_hide(pPrivate->pStatusControl);
     break;
-  case APP_SP_EDIT_FONT:
+    //  case APP_SP_EDIT_FONT:
     // TODO: Editor should handle this directly
-    dasher_main_refresh_font(pSelf);
-    break;
+    //    dasher_main_refresh_font(pSelf);
+    //    break;
 #ifndef WITH_MAEMO
   case LP_MAX_BITRATE:
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(pPrivate->pSpeedBox), dasher_app_settings_get_long(pPrivate->pAppSettings, LP_MAX_BITRATE) / 100.0);
@@ -640,8 +655,11 @@ dasher_main_handle_parameter_change(DasherMain *pSelf, int iParameter) {
 #endif
   }
 
-  // TODO: Pass into editor?
-  dasher_preferences_dialogue_handle_parameter_change(pPrivate->pPreferencesDialogue, iParameter);
+  if(pPrivate->pPreferencesDialogue)
+    dasher_preferences_dialogue_handle_parameter_change(pPrivate->pPreferencesDialogue, iParameter);
+
+  if(pPrivate->pEditor)
+    dasher_editor_handle_parameter_change(pPrivate->pEditor, iParameter);
 }
 
 static void 
@@ -671,6 +689,16 @@ dasher_main_load_state(DasherMain *pSelf) {
 
   pPrivate->iWidth = iWindowWidth;
   pPrivate->iHeight = iWindowHeight;
+
+
+  int iWindowX;
+  int iWindowY;
+ 
+  iWindowX = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_X);
+  iWindowY = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_Y);
+
+  gtk_window_move(GTK_WINDOW(pPrivate->pMainWindow), iWindowX, iWindowY);
+
   
   //  pPrivate->iPosition = dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_DOCK_POSITION);
 }
@@ -700,6 +728,13 @@ dasher_main_save_state(DasherMain *pSelf) {
      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_SCREEN_HEIGHT_H, iWindowHeight);
    } 
 
+   int iWindowX;
+   int iWindowY;
+   gtk_window_get_position(GTK_WINDOW(pPrivate->pMainWindow), &iWindowX, &iWindowY);
+
+   dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_X, iWindowX);
+   dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_Y, iWindowY);
+
    //   dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_DOCK_POSITION, pPrivate->iPosition);
 }
 
@@ -873,6 +908,9 @@ dasher_main_setup_window_style(DasherMain *pSelf) {
     // Fullscreen mode - set fullscreen
     gtk_window_fullscreen(GTK_WINDOW(pPrivate->pMainWindow));
     break;
+  case 22:
+    gtk_window_set_accept_focus(GTK_WINDOW(pPrivate->pMainWindow), false);
+    break;
   default:
     g_error("Inconsistent application style specified.");
   }
@@ -897,16 +935,16 @@ dasher_main_setup_internal_layout(DasherMain *pSelf) {
       gtk_widget_hide(pPrivate->pStatusControl);
   }
 
-  dasher_main_refresh_font(pSelf);
+  //  dasher_main_refresh_font(pSelf);
 }
 
-static void 
-dasher_main_refresh_font(DasherMain *pSelf) {
-  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
+// static void 
+// dasher_main_refresh_font(DasherMain *pSelf) {
+//   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
-  dasher_editor_handle_font(pPrivate->pEditor, 
-			    dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT));
-}
+//   dasher_editor_handle_font(pPrivate->pEditor, 
+// 			    dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT));
+// }
 
 // TODO: Fold into setup controls?
 static void 
@@ -929,7 +967,7 @@ dasher_main_connect_menus(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
   int iNumItems = sizeof(MenuCommands) / sizeof(DasherMenuCommand);
-
+  
   for(int i(0); i < iNumItems; ++i) {
     GtkWidget *pWidget;
 
@@ -944,6 +982,7 @@ dasher_main_connect_menus(DasherMain *pSelf) {
       else
 	g_signal_connect(G_OBJECT(pWidget), "clicked", G_CALLBACK(dasher_main_cb_menu_command), pSelf);
   }
+  
 }
 
 static void 
@@ -1291,11 +1330,15 @@ create_dasher_control(gchar *szName, gchar *szString1, gchar *szString2, gint iI
 
 extern "C" GtkWidget *
 create_dasher_editor(gchar *szName, gchar *szString1, gchar *szString2, gint iInt1, gint iInt2) {
-  // TODO: Do something sensible here (this is only here for test purposes)
-  if(true)
-    return GTK_WIDGET(dasher_editor_internal_new());
-  else
+  g_return_val_if_fail(g_pDasherMain != NULL, NULL);
+
+  DasherMain *pDasherMain = DASHER_MAIN(g_pDasherMain);
+  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
+
+  if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) == 2)
     return GTK_WIDGET(dasher_editor_external_new());
+  else
+    return GTK_WIDGET(dasher_editor_internal_new());
 }
 
 extern "C" gboolean 
